@@ -9,8 +9,6 @@
 
 # cdk-aurora-globaldatabase
 
-# ⛔️ Please do not use cdk v1, because lot of db engine version already not been update in @aws-cdk/aws-rds upstream. ⛔️
-
 `cdk-aurora-globaldatabase` is an AWS CDK construct library that allows you to create [Amazon Aurora Global Databases](https://aws.amazon.com/rds/aurora/global-database/) with AWS CDK in Typescript or Python.
 
 # Why
@@ -33,14 +31,16 @@ npm install cdk-aurora-globaldatabase@latest
 npm install cdk-aurora-globaldatabase@cdkv1
 ```
 
+💡💡💡 please click [here](https://github.com/neilkuan/cdk-aurora-globaldatabase/tree/cdkv1#readme), if you are using aws-cdk v1.x.x version.💡💡💡
+
 ## Now Try It !!!
 
 # Sample for Mysql
 
 ```python
 import { GlobalAuroraRDSMaster, InstanceTypeEnum, GlobalAuroraRDSSlaveInfra } from 'cdk-aurora-globaldatabase';
-import { App, Stack, CfnOutput } from '@aws-cdk/core';
-import * as ec2 from '@aws-cdk/aws-ec2';
+import { App, Stack, CfnOutput } from 'aws-cdk-lib';
+import * as ec2 from 'aws-cdk-lib/aws-ec2';
 // new app .
 const mockApp = new App();
 
@@ -97,9 +97,9 @@ globaldbM.addRegionalCluster(stackM,'addregionalrds',{
 
 ```python
 import { GlobalAuroraRDSMaster, InstanceTypeEnum, GlobalAuroraRDSSlaveInfra } from 'cdk-aurora-globaldatabase';
-import { App, Stack, CfnOutput } from '@aws-cdk/core';
-import * as ec2 from '@aws-cdk/aws-ec2';
-import * as _rds from '@aws-cdk/aws-rds';
+import { App, Stack, CfnOutput } from 'aws-cdk-lib';
+import * as ec2 from 'aws-cdk-lib/aws-ec2';
+import * as _rds from 'aws-cdk-lib/aws-rds';
 
 const mockApp = new App();
 const envSingapro  = { account: process.env.CDK_DEFAULT_ACCOUNT, region: 'ap-southeast-1' };
@@ -191,9 +191,6 @@ cdk destroy
 [![Stargazers repo roster for @neilkuan/cdk-aurora-globaldatabase](https://reporoster.com/stars/neilkuan/cdk-aurora-globaldatabase)](https://github.com/neilkuan/cdk-aurora-globaldatabase/stargazers)
 [![Forkers repo roster for @neilkuan/cdk-aurora-globaldatabase](https://reporoster.com/forks/neilkuan/cdk-aurora-globaldatabase)](https://github.com/neilkuan/cdk-aurora-globaldatabase/network/members)
 '''
-from pkgutil import extend_path
-__path__ = extend_path(__path__, __name__)
-
 import abc
 import builtins
 import datetime
@@ -204,17 +201,16 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
-import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_67de8e8d
-import aws_cdk.aws_rds as _aws_cdk_aws_rds_9543e6d5
-import aws_cdk.core as _aws_cdk_core_f4b25747
+import aws_cdk
+import aws_cdk.aws_ec2
+import aws_cdk.aws_rds
+import constructs
 
 
 class GlobalAuroraRDSMaster(
-    _aws_cdk_core_f4b25747.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-aurora-globaldatabase.GlobalAuroraRDSMaster",
 ):
@@ -224,20 +220,20 @@ class GlobalAuroraRDSMaster(
 
     def __init__(
         self,
-        scope: _aws_cdk_core_f4b25747.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        db_clusterp_pg: typing.Optional[_aws_cdk_aws_rds_9543e6d5.IParameterGroup] = None,
+        db_clusterp_pg: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
         db_user_name: typing.Optional[builtins.str] = None,
         default_database_name: typing.Optional[builtins.str] = None,
         deletion_protection: typing.Optional[builtins.bool] = None,
-        engine_version: typing.Optional[_aws_cdk_aws_rds_9543e6d5.IClusterEngine] = None,
+        engine_version: typing.Optional[aws_cdk.aws_rds.IClusterEngine] = None,
         instance_type: typing.Optional["InstanceTypeEnum"] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         rds_password: typing.Optional[builtins.str] = None,
         storage_encrypted: typing.Optional[builtins.bool] = None,
         time_zone: typing.Optional["MySQLtimeZone"] = None,
-        vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
+        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
         '''
         :param scope: -
@@ -256,10 +252,6 @@ class GlobalAuroraRDSMaster(
 
         :stability: experimental
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__c13bc7cced9e2717fb24c7f8738bf250de911a243342667d0fba6ce263b88f14)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GlobalAuroraRDSMasterProps(
             db_clusterp_pg=db_clusterp_pg,
             db_user_name=db_user_name,
@@ -279,38 +271,27 @@ class GlobalAuroraRDSMaster(
     @jsii.member(jsii_name="addRegionalCluster")
     def add_regional_cluster(
         self,
-        scope: _aws_cdk_core_f4b25747.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         region: builtins.str,
-        db_parameter_group: typing.Optional[builtins.str] = None,
         db_subnet_group_name: typing.Optional[builtins.str] = None,
-        security_group_id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
         :param region: 
-        :param db_parameter_group: 
         :param db_subnet_group_name: 
-        :param security_group_id: 
 
         :stability: experimental
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__badcfde5521673a08053989e4b1c59bf38ad51d1ad5bf03c83a8dfbcec11f8cf)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = RegionalOptions(
-            region=region,
-            db_parameter_group=db_parameter_group,
-            db_subnet_group_name=db_subnet_group_name,
-            security_group_id=security_group_id,
+            region=region, db_subnet_group_name=db_subnet_group_name
         )
 
         return typing.cast(None, jsii.invoke(self, "addRegionalCluster", [scope, id, options]))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="clusterEngineVersion")
     def cluster_engine_version(self) -> builtins.str:
         '''(experimental) return RDS Cluster DB Engine Version.
@@ -319,16 +300,16 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "clusterEngineVersion"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="dbClusterpPG")
-    def db_clusterp_pg(self) -> _aws_cdk_aws_rds_9543e6d5.IParameterGroup:
+    def db_clusterp_pg(self) -> aws_cdk.aws_rds.IParameterGroup:
         '''(experimental) return RDS Cluster ParameterGroup.
 
         :stability: experimental
         '''
-        return typing.cast(_aws_cdk_aws_rds_9543e6d5.IParameterGroup, jsii.get(self, "dbClusterpPG"))
+        return typing.cast(aws_cdk.aws_rds.IParameterGroup, jsii.get(self, "dbClusterpPG"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="engine")
     def engine(self) -> builtins.str:
         '''(experimental) return RDS Cluster DB Engine .
@@ -337,16 +318,16 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "engine"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="engineVersion")
-    def engine_version(self) -> _aws_cdk_aws_rds_9543e6d5.IClusterEngine:
+    def engine_version(self) -> aws_cdk.aws_rds.IClusterEngine:
         '''(experimental) return RDS Cluster DB Engine Version.
 
         :stability: experimental
         '''
-        return typing.cast(_aws_cdk_aws_rds_9543e6d5.IClusterEngine, jsii.get(self, "engineVersion"))
+        return typing.cast(aws_cdk.aws_rds.IClusterEngine, jsii.get(self, "engineVersion"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="globalClusterArn")
     def global_cluster_arn(self) -> builtins.str:
         '''(experimental) return Global RDS Cluster Resource ARN .
@@ -355,7 +336,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "globalClusterArn"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="globalClusterIdentifier")
     def global_cluster_identifier(self) -> builtins.str:
         '''(experimental) return Global RDS Cluster Identifier .
@@ -364,16 +345,16 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "globalClusterIdentifier"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="rdsCluster")
-    def rds_cluster(self) -> _aws_cdk_aws_rds_9543e6d5.DatabaseCluster:
+    def rds_cluster(self) -> aws_cdk.aws_rds.DatabaseCluster:
         '''(experimental) return RDS Cluster.
 
         :stability: experimental
         '''
-        return typing.cast(_aws_cdk_aws_rds_9543e6d5.DatabaseCluster, jsii.get(self, "rdsCluster"))
+        return typing.cast(aws_cdk.aws_rds.DatabaseCluster, jsii.get(self, "rdsCluster"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="rdsClusterarn")
     def rds_clusterarn(self) -> builtins.str:
         '''(experimental) return RDS Cluster Resource ARN .
@@ -382,7 +363,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "rdsClusterarn"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="rdsInstanceType")
     def rds_instance_type(self) -> "InstanceTypeEnum":
         '''(experimental) return Global RDS Cluster instance Type .
@@ -391,16 +372,16 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast("InstanceTypeEnum", jsii.get(self, "rdsInstanceType"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="rdsIsPublic")
-    def rds_is_public(self) -> _aws_cdk_aws_ec2_67de8e8d.SubnetType:
+    def rds_is_public(self) -> aws_cdk.aws_ec2.SubnetType:
         '''(experimental) return RDS Cluster is Public ?
 
         :stability: experimental
         '''
-        return typing.cast(_aws_cdk_aws_ec2_67de8e8d.SubnetType, jsii.get(self, "rdsIsPublic"))
+        return typing.cast(aws_cdk.aws_ec2.SubnetType, jsii.get(self, "rdsIsPublic"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="rdsPassword")
     def rds_password(self) -> typing.Optional[builtins.str]:
         '''(experimental) return RDS Cluster password.
@@ -434,17 +415,17 @@ class GlobalAuroraRDSMasterProps:
     def __init__(
         self,
         *,
-        db_clusterp_pg: typing.Optional[_aws_cdk_aws_rds_9543e6d5.IParameterGroup] = None,
+        db_clusterp_pg: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
         db_user_name: typing.Optional[builtins.str] = None,
         default_database_name: typing.Optional[builtins.str] = None,
         deletion_protection: typing.Optional[builtins.bool] = None,
-        engine_version: typing.Optional[_aws_cdk_aws_rds_9543e6d5.IClusterEngine] = None,
+        engine_version: typing.Optional[aws_cdk.aws_rds.IClusterEngine] = None,
         instance_type: typing.Optional["InstanceTypeEnum"] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         rds_password: typing.Optional[builtins.str] = None,
         storage_encrypted: typing.Optional[builtins.bool] = None,
         time_zone: typing.Optional["MySQLtimeZone"] = None,
-        vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
+        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
         '''
         :param db_clusterp_pg: (experimental) RDS ParameterGroup. Default: - Aurora MySQL ParameterGroup
@@ -461,20 +442,7 @@ class GlobalAuroraRDSMasterProps:
 
         :stability: experimental
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__3c6c13fd4ad0204ebf5aa198a357b7aeeb4063225bb45d2a2d1963db904c8f25)
-            check_type(argname="argument db_clusterp_pg", value=db_clusterp_pg, expected_type=type_hints["db_clusterp_pg"])
-            check_type(argname="argument db_user_name", value=db_user_name, expected_type=type_hints["db_user_name"])
-            check_type(argname="argument default_database_name", value=default_database_name, expected_type=type_hints["default_database_name"])
-            check_type(argname="argument deletion_protection", value=deletion_protection, expected_type=type_hints["deletion_protection"])
-            check_type(argname="argument engine_version", value=engine_version, expected_type=type_hints["engine_version"])
-            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
-            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
-            check_type(argname="argument rds_password", value=rds_password, expected_type=type_hints["rds_password"])
-            check_type(argname="argument storage_encrypted", value=storage_encrypted, expected_type=type_hints["storage_encrypted"])
-            check_type(argname="argument time_zone", value=time_zone, expected_type=type_hints["time_zone"])
-            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
-        self._values: typing.Dict[builtins.str, typing.Any] = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if db_clusterp_pg is not None:
             self._values["db_clusterp_pg"] = db_clusterp_pg
         if db_user_name is not None:
@@ -499,9 +467,7 @@ class GlobalAuroraRDSMasterProps:
             self._values["vpc"] = vpc
 
     @builtins.property
-    def db_clusterp_pg(
-        self,
-    ) -> typing.Optional[_aws_cdk_aws_rds_9543e6d5.IParameterGroup]:
+    def db_clusterp_pg(self) -> typing.Optional[aws_cdk.aws_rds.IParameterGroup]:
         '''(experimental) RDS ParameterGroup.
 
         :default: - Aurora MySQL ParameterGroup
@@ -509,7 +475,7 @@ class GlobalAuroraRDSMasterProps:
         :stability: experimental
         '''
         result = self._values.get("db_clusterp_pg")
-        return typing.cast(typing.Optional[_aws_cdk_aws_rds_9543e6d5.IParameterGroup], result)
+        return typing.cast(typing.Optional[aws_cdk.aws_rds.IParameterGroup], result)
 
     @builtins.property
     def db_user_name(self) -> typing.Optional[builtins.str]:
@@ -545,9 +511,7 @@ class GlobalAuroraRDSMasterProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def engine_version(
-        self,
-    ) -> typing.Optional[_aws_cdk_aws_rds_9543e6d5.IClusterEngine]:
+    def engine_version(self) -> typing.Optional[aws_cdk.aws_rds.IClusterEngine]:
         '''(experimental) RDS Database Cluster Engine .
 
         :default: - rds.DatabaseClusterEngine.auroraMysql({version: rds.AuroraMysqlEngineVersion.VER_2_07_1,})
@@ -555,7 +519,7 @@ class GlobalAuroraRDSMasterProps:
         :stability: experimental
         '''
         result = self._values.get("engine_version")
-        return typing.cast(typing.Optional[_aws_cdk_aws_rds_9543e6d5.IClusterEngine], result)
+        return typing.cast(typing.Optional[aws_cdk.aws_rds.IClusterEngine], result)
 
     @builtins.property
     def instance_type(self) -> typing.Optional["InstanceTypeEnum"]:
@@ -611,7 +575,7 @@ class GlobalAuroraRDSMasterProps:
         return typing.cast(typing.Optional["MySQLtimeZone"], result)
 
     @builtins.property
-    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc]:
+    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
         '''(experimental) RDS default VPC.
 
         :default: - new VPC
@@ -619,7 +583,7 @@ class GlobalAuroraRDSMasterProps:
         :stability: experimental
         '''
         result = self._values.get("vpc")
-        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc], result)
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -634,7 +598,7 @@ class GlobalAuroraRDSMasterProps:
 
 
 class GlobalAuroraRDSSlaveInfra(
-    _aws_cdk_core_f4b25747.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-aurora-globaldatabase.GlobalAuroraRDSSlaveInfra",
 ):
@@ -644,14 +608,14 @@ class GlobalAuroraRDSSlaveInfra(
 
     def __init__(
         self,
-        scope: _aws_cdk_core_f4b25747.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         deletion_protection: typing.Optional[builtins.bool] = None,
-        stack: typing.Optional[_aws_cdk_core_f4b25747.Stack] = None,
+        stack: typing.Optional[aws_cdk.Stack] = None,
         storage_encrypted: typing.Optional[builtins.bool] = None,
-        subnet_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType] = None,
-        vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
+        subnet_type: typing.Optional[aws_cdk.aws_ec2.SubnetType] = None,
+        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
         '''
         :param scope: -
@@ -664,10 +628,6 @@ class GlobalAuroraRDSSlaveInfra(
 
         :stability: experimental
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__adb4e67750ff5091537937b6b35d9eca5cc772324df300a4458ad067e922e5a4)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GlobalAuroraRDSSlaveInfraProps(
             deletion_protection=deletion_protection,
             stack=stack,
@@ -678,16 +638,16 @@ class GlobalAuroraRDSSlaveInfra(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="dbSubnetGroup")
-    def db_subnet_group(self) -> _aws_cdk_aws_rds_9543e6d5.CfnDBSubnetGroup:
-        '''(experimental) GolbalAuroraRDSSlaveInfra subnet group .
+    def db_subnet_group(self) -> aws_cdk.aws_rds.CfnDBSubnetGroup:
+        '''(experimental) GlobalAuroraRDSSlaveInfra subnet group .
 
         :default: - true
 
         :stability: experimental
         '''
-        return typing.cast(_aws_cdk_aws_rds_9543e6d5.CfnDBSubnetGroup, jsii.get(self, "dbSubnetGroup"))
+        return typing.cast(aws_cdk.aws_rds.CfnDBSubnetGroup, jsii.get(self, "dbSubnetGroup"))
 
 
 @jsii.data_type(
@@ -706,10 +666,10 @@ class GlobalAuroraRDSSlaveInfraProps:
         self,
         *,
         deletion_protection: typing.Optional[builtins.bool] = None,
-        stack: typing.Optional[_aws_cdk_core_f4b25747.Stack] = None,
+        stack: typing.Optional[aws_cdk.Stack] = None,
         storage_encrypted: typing.Optional[builtins.bool] = None,
-        subnet_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType] = None,
-        vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
+        subnet_type: typing.Optional[aws_cdk.aws_ec2.SubnetType] = None,
+        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
         '''
         :param deletion_protection: (experimental) Global RDS Database Cluster Engine Deletion Protection Option . Default: - false
@@ -720,14 +680,7 @@ class GlobalAuroraRDSSlaveInfraProps:
 
         :stability: experimental
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__c39e4ab21210972b92f407f65a2785ac0f17bc4af84567cb6ea9c1d68038559e)
-            check_type(argname="argument deletion_protection", value=deletion_protection, expected_type=type_hints["deletion_protection"])
-            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
-            check_type(argname="argument storage_encrypted", value=storage_encrypted, expected_type=type_hints["storage_encrypted"])
-            check_type(argname="argument subnet_type", value=subnet_type, expected_type=type_hints["subnet_type"])
-            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
-        self._values: typing.Dict[builtins.str, typing.Any] = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if deletion_protection is not None:
             self._values["deletion_protection"] = deletion_protection
         if stack is not None:
@@ -751,13 +704,13 @@ class GlobalAuroraRDSSlaveInfraProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def stack(self) -> typing.Optional[_aws_cdk_core_f4b25747.Stack]:
+    def stack(self) -> typing.Optional[aws_cdk.Stack]:
         '''(experimental) RDS Stack.
 
         :stability: experimental
         '''
         result = self._values.get("stack")
-        return typing.cast(typing.Optional[_aws_cdk_core_f4b25747.Stack], result)
+        return typing.cast(typing.Optional[aws_cdk.Stack], result)
 
     @builtins.property
     def storage_encrypted(self) -> typing.Optional[builtins.bool]:
@@ -771,16 +724,16 @@ class GlobalAuroraRDSSlaveInfraProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def subnet_type(self) -> typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType]:
+    def subnet_type(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetType]:
         '''(experimental) Slave region.
 
         :stability: experimental
         '''
         result = self._values.get("subnet_type")
-        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType], result)
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetType], result)
 
     @builtins.property
-    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc]:
+    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
         '''(experimental) Slave region VPC.
 
         :default: - new VPC
@@ -788,7 +741,7 @@ class GlobalAuroraRDSSlaveInfraProps:
         :stability: experimental
         '''
         result = self._values.get("vpc")
-        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc], result)
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1346,45 +1299,26 @@ class MySQLtimeZone(enum.Enum):
 @jsii.data_type(
     jsii_type="cdk-aurora-globaldatabase.RegionalOptions",
     jsii_struct_bases=[],
-    name_mapping={
-        "region": "region",
-        "db_parameter_group": "dbParameterGroup",
-        "db_subnet_group_name": "dbSubnetGroupName",
-        "security_group_id": "securityGroupId",
-    },
+    name_mapping={"region": "region", "db_subnet_group_name": "dbSubnetGroupName"},
 )
 class RegionalOptions:
     def __init__(
         self,
         *,
         region: builtins.str,
-        db_parameter_group: typing.Optional[builtins.str] = None,
         db_subnet_group_name: typing.Optional[builtins.str] = None,
-        security_group_id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param region: 
-        :param db_parameter_group: 
         :param db_subnet_group_name: 
-        :param security_group_id: 
 
         :stability: experimental
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__ff99d9fe334e90bddb6e79ee9bfc45baac91455638cc1bba8b2532159c0e58d6)
-            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
-            check_type(argname="argument db_parameter_group", value=db_parameter_group, expected_type=type_hints["db_parameter_group"])
-            check_type(argname="argument db_subnet_group_name", value=db_subnet_group_name, expected_type=type_hints["db_subnet_group_name"])
-            check_type(argname="argument security_group_id", value=security_group_id, expected_type=type_hints["security_group_id"])
-        self._values: typing.Dict[builtins.str, typing.Any] = {
+        self._values: typing.Dict[str, typing.Any] = {
             "region": region,
         }
-        if db_parameter_group is not None:
-            self._values["db_parameter_group"] = db_parameter_group
         if db_subnet_group_name is not None:
             self._values["db_subnet_group_name"] = db_subnet_group_name
-        if security_group_id is not None:
-            self._values["security_group_id"] = security_group_id
 
     @builtins.property
     def region(self) -> builtins.str:
@@ -1395,14 +1329,6 @@ class RegionalOptions:
         assert result is not None, "Required property 'region' is missing"
         return typing.cast(builtins.str, result)
 
-    @builtins.property
-    def db_parameter_group(self) -> typing.Optional[builtins.str]:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("db_parameter_group")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def db_subnet_group_name(self) -> typing.Optional[builtins.str]:
         '''
@@ -1411,14 +1337,6 @@ class RegionalOptions:
         result = self._values.get("db_subnet_group_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
-    @builtins.property
-    def security_group_id(self) -> typing.Optional[builtins.str]:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("security_group_id")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1442,85 +1360,3 @@ __all__ = [
 ]
 
 publication.publish()
-
-def _typecheckingstub__c13bc7cced9e2717fb24c7f8738bf250de911a243342667d0fba6ce263b88f14(
-    scope: _aws_cdk_core_f4b25747.Construct,
-    id: builtins.str,
-    *,
-    db_clusterp_pg: typing.Optional[_aws_cdk_aws_rds_9543e6d5.IParameterGroup] = None,
-    db_user_name: typing.Optional[builtins.str] = None,
-    default_database_name: typing.Optional[builtins.str] = None,
-    deletion_protection: typing.Optional[builtins.bool] = None,
-    engine_version: typing.Optional[_aws_cdk_aws_rds_9543e6d5.IClusterEngine] = None,
-    instance_type: typing.Optional[InstanceTypeEnum] = None,
-    parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-    rds_password: typing.Optional[builtins.str] = None,
-    storage_encrypted: typing.Optional[builtins.bool] = None,
-    time_zone: typing.Optional[MySQLtimeZone] = None,
-    vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__badcfde5521673a08053989e4b1c59bf38ad51d1ad5bf03c83a8dfbcec11f8cf(
-    scope: _aws_cdk_core_f4b25747.Construct,
-    id: builtins.str,
-    *,
-    region: builtins.str,
-    db_parameter_group: typing.Optional[builtins.str] = None,
-    db_subnet_group_name: typing.Optional[builtins.str] = None,
-    security_group_id: typing.Optional[builtins.str] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__3c6c13fd4ad0204ebf5aa198a357b7aeeb4063225bb45d2a2d1963db904c8f25(
-    *,
-    db_clusterp_pg: typing.Optional[_aws_cdk_aws_rds_9543e6d5.IParameterGroup] = None,
-    db_user_name: typing.Optional[builtins.str] = None,
-    default_database_name: typing.Optional[builtins.str] = None,
-    deletion_protection: typing.Optional[builtins.bool] = None,
-    engine_version: typing.Optional[_aws_cdk_aws_rds_9543e6d5.IClusterEngine] = None,
-    instance_type: typing.Optional[InstanceTypeEnum] = None,
-    parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-    rds_password: typing.Optional[builtins.str] = None,
-    storage_encrypted: typing.Optional[builtins.bool] = None,
-    time_zone: typing.Optional[MySQLtimeZone] = None,
-    vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__adb4e67750ff5091537937b6b35d9eca5cc772324df300a4458ad067e922e5a4(
-    scope: _aws_cdk_core_f4b25747.Construct,
-    id: builtins.str,
-    *,
-    deletion_protection: typing.Optional[builtins.bool] = None,
-    stack: typing.Optional[_aws_cdk_core_f4b25747.Stack] = None,
-    storage_encrypted: typing.Optional[builtins.bool] = None,
-    subnet_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType] = None,
-    vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__c39e4ab21210972b92f407f65a2785ac0f17bc4af84567cb6ea9c1d68038559e(
-    *,
-    deletion_protection: typing.Optional[builtins.bool] = None,
-    stack: typing.Optional[_aws_cdk_core_f4b25747.Stack] = None,
-    storage_encrypted: typing.Optional[builtins.bool] = None,
-    subnet_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType] = None,
-    vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__ff99d9fe334e90bddb6e79ee9bfc45baac91455638cc1bba8b2532159c0e58d6(
-    *,
-    region: builtins.str,
-    db_parameter_group: typing.Optional[builtins.str] = None,
-    db_subnet_group_name: typing.Optional[builtins.str] = None,
-    security_group_id: typing.Optional[builtins.str] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
